============================
NEWS for lazr.batchnavigator
============================

1.3.1 (2021-09-13)
==================

- Adjust versioning strategy to avoid importing pkg_resources, which is slow
  in large environments.

1.3.0 (2019-11-04)
==================

- Switch from buildout to tox.
- Add Python 3 support.

1.2.11 (2015-04-09)
===================

- Save a query if the slice is of the form [x:x].

1.2.10 (2011-09-14)
===================

- delegate the calculation of the rough length of a result set to
  IRangeFactory.

1.2.9 (2011-08-25)
==================

- When a backwards batch is at first too short and when another chunk
  from the result set is added, _Batch,sliced_list() does no longer
  use the memo value for the already retrived chunk.

- don't use the parameter start to determine if a previous/next batch
  exists; don't rely on len(resultset) and  to determine the real size
  of a batch.

- Avoid negative start index on empty result sets.

1.2.7 (2011-07-18)
==================

- retrieve slices of the result set in class _Batch only via methods
  of the range factory.

1.2.6 (2011-07-28)
==================

- fixed an error in handling backwards batches which return less elements
  than expected.
- URL-encode all query parameters in BatchNavigator.generateBatchURL()

1.2.5 (2011-07-13)
==================

- Permit changing all variable names with a single prefix.

1.2.4 (2011-04-11)
==================

- Permit overriding determineSize to control how the batch default and concrete
  sizes are determined in subclasses.
- Listify (once we have sliced) rather than assuming batched slices will honour
  the complete list protocol.

1.2.3 (2011-04-06)
==================

- Add IRangeFactory and the ability to use backend database hints for efficient
  retrieval of pages.

- Remove terrible-scaling getBatchURLs method.

1.2.2 (2010-08-19)
==================

- Make len() cheap to call when the current batch is the last (or
  only) batch.

- Avoid calling len() when generating navigator URLs.

1.2.1 (2010-08-12)
==================

- fix a bug in the len() of a batch when the batch had previously been
  iterated over

1.2.0 (2010-08-05)
==================

- avoid calling len() on the underlying sequence when possible
- return None for endNumber when the batch is out of range

1.1.1 (2010-05-10)
==================

- Ignore negative batch sizes

1.1 (2009-08-31)
================

- Remove build dependencies on bzr and egg_info

- remove sys.path hack in setup.py for __version__

1.0 (2009-03-24)
================

- Initial release on PyPI
